@@ -14,47 +14,43 @@ import (
 	"github.com/sirupsen/logrus"
 
 	corev1 "k8s.io/api/core/v1"
-	corev1client "k8s.io/client-go/kubernetes/typed/core/v1"
-	corev1lister "k8s.io/client-go/listers/core/v1"
-
 	kerrors "k8s.io/apimachinery/pkg/api/errors"
 	kapis "k8s.io/apimachinery/pkg/apis/meta/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	utilnet "k8s.io/apimachinery/pkg/util/net"
 	"k8s.io/apimachinery/pkg/util/wait"
-
+	corev1client "k8s.io/client-go/kubernetes/typed/core/v1"
+	corev1lister "k8s.io/client-go/listers/core/v1"
 	restclient "k8s.io/client-go/rest"
 	"k8s.io/client-go/util/retry"
 
 	imagev1 "github.com/openshift/api/image/v1"
+	operatorsv1api "github.com/openshift/api/operator/v1"
+	v1 "github.com/openshift/api/samples/v1"
 	templatev1 "github.com/openshift/api/template/v1"
-
 	configv1client "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
 	imagev1client "github.com/openshift/client-go/image/clientset/versioned/typed/image/v1"
 	imagev1lister "github.com/openshift/client-go/image/listers/image/v1"
+	sampleclientv1 "github.com/openshift/client-go/samples/clientset/versioned/typed/samples/v1"
 	configv1lister "github.com/openshift/client-go/samples/listers/samples/v1"
 	templatev1client "github.com/openshift/client-go/template/clientset/versioned/typed/template/v1"
 	templatev1lister "github.com/openshift/client-go/template/listers/template/v1"
 
-	operatorsv1api "github.com/openshift/api/operator/v1"
-	v1 "github.com/openshift/api/samples/v1"
 	"github.com/openshift/cluster-samples-operator/pkg/cache"
 	sampopclient "github.com/openshift/cluster-samples-operator/pkg/client"
 	"github.com/openshift/cluster-samples-operator/pkg/metrics"
 	operatorstatus "github.com/openshift/cluster-samples-operator/pkg/operatorstatus"
 	"github.com/openshift/cluster-samples-operator/pkg/util"
-
-	sampleclientv1 "github.com/openshift/client-go/samples/clientset/versioned/typed/samples/v1"
 )
 
 const (
-	x86OCPContentRootDir = "/opt/openshift/operator/ocp-x86_64"
-	ppcOCPContentRootDir = "/opt/openshift/operator/ocp-ppc64le"
-	zOCPContentRootDir   = "/opt/openshift/operator/ocp-s390x"
-	installtypekey       = "keyForInstallTypeField"
-	regkey               = "keyForSamplesRegistryField"
-	skippedstreamskey    = "keyForSkippedImageStreamsField"
-	skippedtempskey      = "keyForSkippedTemplatesField"
+	x86ContentRootDir = "/opt/openshift/operator/x86_64"
+	ppcContentRootDir = "/opt/openshift/operator/ppc64le"
+	zContentRootDir   = "/opt/openshift/operator/s390x"
+	installtypekey    = "keyForInstallTypeField"
+	regkey            = "keyForSamplesRegistryField"
+	skippedstreamskey = "keyForSkippedImageStreamsField"
+	skippedtempskey   = "keyForSkippedTemplatesField"
 )
 
 func NewSamplesOperatorHandler(kubeconfig *restclient.Config,
